Enum mimerrust::ScrollOption

source ·
pub enum ScrollOption {
    NEXT,
    PREVIOUS,
    RELATIVE,
    ABSOLUTE,
    FIRST,
    LAST,
}
Scroll options used in scroll.

Variants



NEXT

Move to the next row.



PREVIOUS

Move to the previous row.



RELATIVE

Move to a row number relative to the current position.



ABSOLUTE

Move to an absolute row number.



FIRST

Move to the first row of the result set.



LAST

Move to the last row of the result set.